@@ -2,7 +2,7 @@
 #define _STRINGUTIL_H_
 
 #include "R.h"
-#include <string.h> // for strlen
+#include <string.h>  // for strlen
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
@@ -16,14 +16,17 @@
 /** tokenize the string
  * @return number of tokens we obtained
  * Special case:
- * For empty input string, we will return 1, and @param result will have only 1 element (the empty string)
- * When delim is empty, we will give warning, return 1, and @param result will have the whole input string
+ * For empty input string, we will return 1, and @param result will have only 1
+ * element (the empty string)
+ * When delim is empty, we will give warning, return 1, and @param result will
+ * have the whole input string
  */
-inline int stringTokenize(const std::string& str, const std::string& delim, std::vector<std::string>* result){
+inline int stringTokenize(const std::string& str, const std::string& delim,
+                          std::vector<std::string>* result) {
   assert(result);
   result->clear();
   if (!delim.size()) {
-    REprintf( "stringTokenize() using an empty delim");
+    REprintf("stringTokenize() using an empty delim");
     result->push_back(str);
     return -1;
   }
@@ -32,7 +35,7 @@ inline int stringTokenize(const std::string& str, const std::string& delim, std:
   unsigned int l = str.size();
   unsigned int i = 0;
   while (i < l) {
-    if (delim.find(str[i]) != std::string::npos) { // it's a delimeter
+    if (delim.find(str[i]) != std::string::npos) {  // it's a delimeter
       result->push_back(s);
       s.clear();
     } else {
@@ -44,32 +47,37 @@ inline int stringTokenize(const std::string& str, const std::string& delim, std:
   return result->size();
 }
 
-inline int stringTokenize(const std::string& str, const char delim, std::vector<std::string>* result){
-    std::string d;
-    d.push_back(delim);
-    return (stringTokenize(str, d, result));
+inline int stringTokenize(const std::string& str, const char delim,
+                          std::vector<std::string>* result) {
+  std::string d;
+  d.push_back(delim);
+  return (stringTokenize(str, d, result));
 }
 
-inline bool isEmptyString(const std::string& s){
-    return s.size() == 0;
-}
-/* int stringNaturalTokenize(const std::string& str, const std::string& delim, std::vector<std::string>* result){ */
+inline bool isEmptyString(const std::string& s) { return s.size() == 0; }
+/* int stringNaturalTokenize(const std::string& str, const std::string& delim,
+ * std::vector<std::string>* result){ */
 /*     int ret = stringTokenize(str, delim, result); */
-/*     ret = remove_if(result->begin(), result->end(), isEmptyString) - result->begin(); */
+/*     ret = remove_if(result->begin(), result->end(), isEmptyString) -
+ * result->begin(); */
 /*     result->resize(ret); */
 /*     return ret; */
 /* }; */
-/* int stringNaturalTokenize(const std::string& str, const char delim, std::vector<std::string>* result){ */
+/* int stringNaturalTokenize(const std::string& str, const char delim,
+ * std::vector<std::string>* result){ */
 /*     std::string d; */
 /*     return (stringNaturalTokenize(str, d, result)); */
 /* }; */
 
-// pretty much like stringTokenize, but @param result will not contain empty string
-inline int stringNaturalTokenize(const std::string& str, const std::string& delim, std::vector<std::string>* result){
+// pretty much like stringTokenize, but @param result will not contain empty
+// string
+inline int stringNaturalTokenize(const std::string& str,
+                                 const std::string& delim,
+                                 std::vector<std::string>* result) {
   assert(result);
   result->clear();
   if (!delim.size()) {
-    REprintf( "stringTokenize() using an empty delim");
+    REprintf("stringTokenize() using an empty delim");
     result->push_back(str);
     return -1;
   }
@@ -77,8 +85,8 @@ inline int stringNaturalTokenize(const std::string& str, const std::string& deli
   unsigned int l = str.size();
   unsigned int i = 0;
   while (i < l) {
-    if (delim.find(str[i]) != std::string::npos) { // it's a delimeter
-      if (s.size()>0){
+    if (delim.find(str[i]) != std::string::npos) {  // it's a delimeter
+      if (s.size() > 0) {
         result->push_back(s);
         s.clear();
       }
@@ -87,76 +95,81 @@ inline int stringNaturalTokenize(const std::string& str, const std::string& deli
     }
     ++i;
   }
-  if (s.size() > 0)
-    result->push_back(s);
+  if (s.size() > 0) result->push_back(s);
   return result->size();
 }
 
-inline int stringNaturalTokenize(const std::string& str, const char delim, std::vector<std::string>* result){
+inline int stringNaturalTokenize(const std::string& str, const char delim,
+                                 std::vector<std::string>* result) {
   std::string d(1, delim);
   return (stringNaturalTokenize(str, d, result));
 }
 
-//remove leading and trailing characters
+// remove leading and trailing characters
 inline void stringStrip(std::string* input, const char* characters = " ") {
   if (!input || !input->size()) return;
-    size_t beg = input->find_first_not_of(characters);
-    size_t end = input->find_last_not_of(characters);
-    input->assign( input->substr(beg, end - beg + 1) );
+  size_t beg = input->find_first_not_of(characters);
+  if (beg == std::string::npos) {
+    return;
+  }
+  size_t end = input->find_last_not_of(characters);
+  input->assign(input->substr(beg, end - beg + 1));
 }
 
 // remove the leading and trailing white spaces
-inline std::string stringStrip(const std::string& s){
-  unsigned int beg = s.find_first_not_of(' ');
-  unsigned int end = s.find_last_not_of(' ');
-  return s.substr(beg, end-beg);
+inline std::string stringStrip(const std::string& s) {
+  size_t beg = s.find_first_not_of(' ');
+  if (beg == std::string::npos) {
+    return "";
+  }
+  size_t end = s.find_last_not_of(' ');
+  return s.substr(beg, end - beg);
 }
 
-//extract piece of string from @param beg(inclusive) to @param end(exclusive)
-//NOTE: beg and end can be negative meaning count from right hand side. 
+// extract piece of string from @param beg(inclusive) to @param end(exclusive)
+// NOTE: beg and end can be negative meaning count from right hand side.
 inline void stringSlice(std::string* input, int beg, int end) {
-    assert(input);
-    unsigned int len = input->size();
-    if (beg < 0) beg += len;
-    if (end < 0) end += len;
-    assert (beg >= 0 && end >= 0);
-    input -> assign ( input->substr(beg, end- beg)) ;
+  assert(input);
+  unsigned int len = input->size();
+  if (beg < 0) beg += len;
+  if (end < 0) end += len;
+  assert(beg >= 0 && end >= 0);
+  input->assign(input->substr(beg, end - beg));
 }
 
 template <class T>
 std::string stringJoin(const std::vector<std::string>& input, const T delim) {
-    std::string s;
-    if (input.size() == 0) {
-        return s;
-    }
-    s = input[0];
-    for (unsigned int i = 1; i < input.size(); i++) {
-        s+= delim;
-        s+= input[i];
-    }
+  std::string s;
+  if (input.size() == 0) {
     return s;
+  }
+  s = input[0];
+  for (unsigned int i = 1; i < input.size(); i++) {
+    s += delim;
+    s += input[i];
+  }
+  return s;
 }
 /**
  * for std::string type, we use reference to save memory.
  */
 template <>
-inline std::string stringJoin<const std::string&>(const std::vector<std::string>& input, const std::string& delim) {
-    std::string s;
-    if (input.size() == 0) {
-        return s;
-    }
-    s = input[0];
-    for (unsigned int i = 1; i < input.size(); i++) {
-        s+= delim;
-        s+= input[i];
-    }
+inline std::string stringJoin<const std::string&>(
+    const std::vector<std::string>& input, const std::string& delim) {
+  std::string s;
+  if (input.size() == 0) {
     return s;
+  }
+  s = input[0];
+  for (unsigned int i = 1; i < input.size(); i++) {
+    s += delim;
+    s += input[i];
+  }
+  return s;
 }
 
 inline void tolower(std::string* s) {
-  for (std::string::iterator i = s->begin();
-       i != s->end();
-       ++i)
+  for (std::string::iterator i = s->begin(); i != s->end(); ++i)
     (*i) = tolower(*i);
 }
 
@@ -167,9 +180,7 @@ inline std::string tolower(const std::string& s) {
 }
 
 inline void toupper(std::string* s) {
-  for (std::string::iterator i = s->begin();
-       i != s->end();
-       ++i)
+  for (std::string::iterator i = s->begin(); i != s->end(); ++i)
     (*i) = toupper(*i);
 }
 
@@ -196,25 +207,23 @@ inline std::string toupper(const std::string& s) {
 
 // remove the leading 'chr' if any
 inline std::string chopChr(const std::string& s) {
-    if (s.size() > 3 && 
-        (s[0] == 'c' || s[0] == 'C') &&
-        (s[1] == 'h' || s[1] == 'H') &&
-        (s[2] == 'r' || s[2] == 'R')){
-        return s.substr(3);
-    }
-    return s;
+  if (s.size() > 3 && (s[0] == 'c' || s[0] == 'C') &&
+      (s[1] == 'h' || s[1] == 'H') && (s[2] == 'r' || s[2] == 'R')) {
+    return s.substr(3);
+  }
+  return s;
 }
 
 static char _bufferStr[128];
 // convert number to char*
 inline const char* toStr(const int i) {
-    sprintf(_bufferStr, "%d", i);
-    return _bufferStr;
+  sprintf(_bufferStr, "%d", i);
+  return _bufferStr;
 }
 
 inline const char* toStr(const double d) {
-    sprintf(_bufferStr, "%g", d);
-    return _bufferStr;
+  sprintf(_bufferStr, "%g", d);
+  return _bufferStr;
 }
 
 /* void tolower(std::string* s) { */
@@ -234,7 +243,7 @@ inline const char* toStr(const double d) {
  */
 inline void dumpStringVector(const std::vector<std::string> s) {
   for (unsigned int i = 0; i < s.size(); i++) {
-    Rprintf( "%u: %s\n", i, s[i].c_str());
+    Rprintf("%u: %s\n", i, s[i].c_str());
   }
 }
 
@@ -257,16 +266,14 @@ inline bool endsWith(const std::string& s, const std::string& tail) {
  * Remove duplicated element from @param input and store it to @param output
  * @return number of duplicated elements
  */
-template<class T>
-inline int dedup(const std::vector<T>& input,
-          std::vector<T>* output) {
+template <class T>
+inline int dedup(const std::vector<T>& input, std::vector<T>* output) {
   int ret = 0;
   assert(output);
   output->clear();
   std::set<T> checked;
   for (typename std::vector<T>::const_iterator it = input.begin();
-       it != input.end();
-       ++it) {
+       it != input.end(); ++it) {
     if (checked.count(*it)) {
       ++ret;
       continue;
@@ -280,12 +287,12 @@ inline int dedup(const std::vector<T>& input,
 /**
  * Remove duplicated element from @param input
  */
-template<class T>
+template <class T>
 int dedup(std::vector<T>* input) {
   assert(input);
   int ret = 0;
   if (input->empty()) return ret;
-  
+
   std::set<T> checked;
   size_t n = input->size();
   size_t i = 0;
@@ -309,10 +316,8 @@ int dedup(std::vector<T>* input) {
 
 // @return true: if @param s has leading "chr", "CHR", "Chr"...
 inline bool hasLeadingChr(const std::string& s) {
-  if (s.size() > 3 &&
-      (s[0] == 'c' || s[0] == 'C') &&
-      (s[1] == 'h' || s[1] == 'H') &&
-      (s[2] == 'r' || s[2] == 'R')){
+  if (s.size() > 3 && (s[0] == 'c' || s[0] == 'C') &&
+      (s[1] == 'h' || s[1] == 'H') && (s[2] == 'r' || s[2] == 'R')) {
     return true;
   }
   return false;
@@ -325,15 +330,13 @@ inline bool hasLeadingChr(const std::string& s) {
  *   for "a ", split to "a", ""
  *   for "", split to ""
  */
-class StringTokenizer{
+class StringTokenizer {
  public:
-  StringTokenizer(const std::string& i, char token):
-            data(i) {
+  StringTokenizer(const std::string& i, char token) : data(i) {
     this->token = token;
     reset();
   }
-  StringTokenizer(const std::string& i, const std::string& token):
-            data(i) {
+  StringTokenizer(const std::string& i, const std::string& token) : data(i) {
     this->token = token;
     reset();
   }
@@ -349,29 +352,29 @@ class StringTokenizer{
     std::string& s = *piece;
     s.clear();
     while (begin <= end) {
-          if (begin == end) {
-            ++ begin;
-            return true;
-          }
+      if (begin == end) {
+        ++begin;
+        return true;
+      }
 
-
-          const char& c = data[begin];
-          if (token.find(c) == std::string::npos) {
-            // not a token
-            s.push_back(c);
-            ++begin;
-          } else {
-            ++begin;
-            return begin < end;
-          }
+      const char& c = data[begin];
+      if (token.find(c) == std::string::npos) {
+        // not a token
+        s.push_back(c);
+        ++begin;
+      } else {
+        ++begin;
+        return begin < end;
+      }
     }
     return begin <= end;
   }
+
  private:
   const std::string& data;
   std::string token;
   size_t begin;
   size_t end;
-}; // StringTokenizer
+};  // StringTokenizer
 
 #endif /* _STRINGUTIL_H_ */
